@@ -7,6 +7,8 @@
  * Contract with IBM Corp.
  *******************************************************************************/
 /* Copyright (c) 2020 Red Hat, Inc. */
+/* Copyright Contributors to the Open Cluster Management project */
+
 'use strict'
 
 const warnPackTypeStr = 'Warning:  pack() Type '
@@ -227,11 +229,6 @@ class YamlInline {
         throw new YamlParseException(`Malformed inline YAML string (${scalar}).`)
       }
 
-      // unended inline string
-      const end = output.slice(-1)
-      if (end === '}' || end === ']') {
-        throw new YamlParseException(`Malformed inline YAML string (${scalar}).`)
-      }
       output = evaluate ? this.evaluateScalar(output) : output
     }
 
@@ -797,8 +794,8 @@ class YamlParser {
           key = new YamlInline().parseScalar(values.key)
         } catch (e) {
           if (e instanceof YamlParseException) {
-            e.setParsedLine(this.getRealCurrentLineNb() + 1)
-            e.setSnippet(this.currentLine)
+            e.parsedLine = this.getRealCurrentLineNb() + 1
+            e.snippet = this.currentLine
           }
           throw e
         }
@@ -898,8 +895,8 @@ class YamlParser {
             value = new YamlInline().parse(this.lines[0])
           } catch (e) {
             if (e instanceof YamlParseException) {
-              e.setParsedLine(this.getRealCurrentLineNb() + 1)
-              e.setSnippet(this.currentLine)
+              e.parsedLine = this.getRealCurrentLineNb() + 1
+              e.snippet = this.currentLine
             }
             throw e
           }
@@ -1139,8 +1136,8 @@ class YamlParser {
       return new YamlInline().parse(value)
     } catch (e) {
       if (e instanceof YamlParseException) {
-        e.setParsedLine(this.getRealCurrentLineNb() + 1)
-        e.setSnippet(this.currentLine)
+        e.parsedLine = this.getRealCurrentLineNb() + 1
+        e.snippet = this.currentLine
       }
       throw e
     }
