@@ -1,29 +1,23 @@
-/*******************************************************************************
- * Licensed Materials - Property of IBM
- * (c) Copyright IBM Corporation 2019. All Rights Reserved.
- *
- * Note to U.S. Government Users Restricted Rights:
- * Use, duplication or disclosure restricted by GSA ADP Schedule
- * Contract with IBM Corp.
- *******************************************************************************/
-/* Copyright (c) 2020 Red Hat, Inc. */
+/* Copyright (c) 2021 Red Hat, Inc. */
+/* Copyright Contributors to the Open Cluster Management project */
+
 'use strict'
 
 import React from 'react'
 import PropTypes from 'prop-types'
-import { Query } from 'react-apollo'
-import { RESOURCE_TYPES } from '../../lib/shared/constants'
-import { createResources, createAndUpdateResources, updateSecondaryHeader,
+import { Query } from '@apollo/client/react/components'
+import { RESOURCE_TYPES } from '../utils/constants'
+import { createResources, createAndUpdateResources,
   clearRequestStatus, fetchSingleResource } from '../actions/common'
 import { withRouter, Redirect } from 'react-router-dom'
 import { connect } from 'react-redux'
-import Page from '../components/common/Page'
-import { CREATE_POLICY_DISCOVERY } from '../../lib/client/queries'
+import { CREATE_POLICY_DISCOVERY, EDIT_POLICY_DISCOVERY } from '../utils/client/queries'
 import CreationView from '../components/modules/CreationView'
-import msgs from '../../nls/platform.properties'
-import config from '../../lib/shared/config'
-import checkCreatePermission from '../components/common/CheckCreatePermission'
+import msgs from '../nls/platform.properties'
+import config from '../../server/lib/shared/config'
+import { checkCreatePermission, checkEditPermission } from '../utils/CheckUserPermission'
 import { LocaleContext } from '../components/common/LocaleContext'
+import { AcmButton, AcmPageContent, AcmPageHeader } from '@open-cluster-management/ui-components'
 
 export class CreationTab extends React.Component {
 
@@ -41,36 +35,15 @@ export class CreationTab extends React.Component {
     handleCreateAndUpdateResources: PropTypes.func,
     handleCreateResources: PropTypes.func,
     handleFetchResource: PropTypes.func,
+    match: PropTypes.object,
     mutateErrorMsg: PropTypes.string,
     mutatePBErrorMsg: PropTypes.string,
     mutatePRErrorMsg: PropTypes.string,
     mutateStatus: PropTypes.string,
-    secondaryHeaderProps: PropTypes.object,
-    updateSecondaryHeader: PropTypes.func,
     updateStatus: PropTypes.string,
     userAccess: PropTypes.array
   }
 
-  UNSAFE_componentWillMount() {
-    const { updateSecondaryHeader:localUpdateSecondaryHeader, secondaryHeaderProps } = this.props
-    const { title, tabs, breadcrumbItems, information } = secondaryHeaderProps
-    const portals = [
-      {
-        id: 'edit-button-portal-id',
-        kind: 'portal',
-        title: true,
-      },
-      {
-        id: 'cancel-button-portal-id',
-        kind: 'portal',
-      },
-      {
-        id: 'create-button-portal-id',
-        kind: 'portal',
-      }]
-    localUpdateSecondaryHeader(msgs.get(title, this.context.locale), tabs, breadcrumbItems, portals, msgs.get(information, this.context.locale))
-  }
-
   handleCreate = (resourceJSON) => {
     if (resourceJSON) {
       const {handleCreateResources} = this.props
@@ -200,61 +173,94 @@ export class CreationTab extends React.Component {
   }
 
   render () {
-    const { mutateStatus, mutateErrorMsg, mutatePBErrorMsg, mutatePRErrorMsg, updateStatus, userAccess } = this.props
+    const { mutateStatus, mutateErrorMsg, mutatePBErrorMsg, mutatePRErrorMsg, updateStatus, userAccess,
+      match : {
+        params: {
+          name,
+          namespace,
+        }
+      }
+    } = this.props
+    const isEdit = namespace !== undefined && name !== undefined
     const { updateRequested } = this.state
-    if (checkCreatePermission(userAccess) !== 1) {
+    const { locale } = this.context
+    const hasPermission = isEdit ? checkEditPermission(userAccess) === 0 : checkCreatePermission(userAccess) === 0
+    if (userAccess && userAccess.length > 0 && hasPermission) {
       return <Redirect to={`${config.contextPath}/all`} />
     }
     if ((mutateStatus && mutateStatus === 'DONE') && (!updateRequested || (updateStatus && updateStatus === 'DONE'))) {
       this.props.cleanReqStatus && this.props.cleanReqStatus()
       return <Redirect to={`${config.contextPath}/all`} />
     }
+    const query = isEdit ? EDIT_POLICY_DISCOVERY : CREATE_POLICY_DISCOVERY
     return (
-      <Page>
-        <Query query={CREATE_POLICY_DISCOVERY}>
-          {( result ) => {
-            const { loading } = result
-            const { data={} } = result
-            const { discoveries } = data
-            const errored = discoveries ? false : true
-            const error = discoveries ? null : result.error
-            if (!loading && error) {
-              const errorName = result.error.graphQLErrors[0].name ? result.error.graphQLErrors[0].name : error.name
-              error.name = errorName
+      <Query query={query} variables={{ name, namespace }}>
+        {( result ) => {
+          const { loading } = result
+          const { data={} } = result
+          const { discoveries, policyDiscoveries } = data
+          const errored = discoveries ? false : true
+          const error = discoveries ? null : result.error
+          if (!loading && error) {
+            if (error.graphQLErrors.length > 0) {
+              error.name = error.graphQLErrors[0].name
             }
-            const fetchControl = {
-              isLoaded: !loading,
-              isFailed: errored,
-              error: error
-            }
-            const buildControl = {
-              buildResourceLists: this.buildCreateUpdateLists.bind(this),
-            }
-            const createControl = {
-              createResource: this.handleCreate.bind(this),
-              cancelCreate: this.handleCancel.bind(this),
-              creationStatus: mutateStatus,
-              creationMsg: mutateErrorMsg,
-            }
-            const createAndUpdateControl = {
-              createAndUpdateResource: this.handleCreateAndUpdate.bind(this),
-              cancelCreateAndUpdate: this.handleCancel.bind(this),
-              createAndUpdateStatus: updateStatus,
-              createAndUpdateMsg: this.formatUpdateError(this.formatUpdateError(mutatePBErrorMsg, mutateErrorMsg), mutatePRErrorMsg),
-            }
-            return (
-              <CreationView
-                discovered={discoveries}
-                fetchControl={fetchControl}
-                createControl={createControl}
-                buildControl={buildControl}
-                createAndUpdateControl={createAndUpdateControl}
-              />
-            )
           }
+          const fetchControl = {
+            isLoaded: !loading,
+            isFailed: errored,
+            error: error
           }
-        </Query>
-      </Page>
+          const buildControl = {
+            buildResourceLists: this.buildCreateUpdateLists.bind(this),
+          }
+          const createControl = {
+            createResource: this.handleCreate.bind(this),
+            cancelCreate: this.handleCancel.bind(this),
+            creationStatus: mutateStatus,
+            creationMsg: mutateErrorMsg,
+          }
+          const createAndUpdateControl = {
+            createAndUpdateResource: this.handleCreateAndUpdate.bind(this),
+            cancelCreateAndUpdate: this.handleCancel.bind(this),
+            createAndUpdateStatus: updateStatus,
+            createAndUpdateMsg: this.formatUpdateError(this.formatUpdateError(mutatePBErrorMsg, mutateErrorMsg), mutatePRErrorMsg),
+          }
+          return (
+            <React.Fragment>
+              <AcmPageHeader title={isEdit?msgs.get('button.edit.policy', locale):msgs.get('button.create.policy', locale)}
+                titleTooltip={msgs.get('policy.create.tooltip', locale)}
+                controls={
+                  <React.Fragment>
+                    <div className='page-header-button-group'>
+                      <AcmButton id='cancel' variant='secondary'
+                        onClick={() => this.handleCancel()}>
+                        {msgs.get('button.cancel', locale)}
+                      </AcmButton>
+                      <AcmButton id={isEdit?'edit':'create'}
+                        tooltip={msgs.get('error.permission.disabled', locale)}
+                        onClick={() => this.clickChild()}>
+                        {isEdit?msgs.get('button.save', locale):msgs.get('button.create', locale)}
+                      </AcmButton>
+                    </div>
+                  </React.Fragment>
+                }>
+              </AcmPageHeader>
+              <AcmPageContent>
+                <CreationView
+                  onCreate={click => this.clickChild = click}
+                  policyDiscovered={policyDiscoveries && policyDiscoveries[0]}
+                  discovered={discoveries}
+                  fetchControl={fetchControl}
+                  createControl={createControl}
+                  buildControl={buildControl}
+                  createAndUpdateControl={createAndUpdateControl}
+                />
+              </AcmPageContent>
+            </React.Fragment>
+          )
+        }}
+      </Query>
     )
   }
 }
@@ -282,7 +288,6 @@ const mapStateToProps = (state) => {
 
 const mapDispatchToProps = (dispatch) => {
   return {
-    updateSecondaryHeader: (title, tabs, breadcrumbItems, links, information) => dispatch(updateSecondaryHeader(title, tabs, breadcrumbItems, links, '', information)),
     handleCreateResources: (type, json) => dispatch(createResources(type, json)),
     handleCreateAndUpdateResources: (types, create, update) => dispatch(createAndUpdateResources(types, create, update)),
     handleFetchResource: (type, json) => dispatch(fetchSingleResource(type, json)),
