@@ -7,18 +7,31 @@
  * Contract with IBM Corp.
  *******************************************************************************/
 /* Copyright (c) 2020 Red Hat, Inc. */
+/* Copyright Contributors to the Open Cluster Management project */
+
 'use strict'
 
 import React from 'react'
 import { shallow } from 'enzyme'
 import { CreationTab } from '../../../src-web/containers/CreationTab'
 
+const match = {
+  'path': '/multicloud/policies/all/:namespace/:name',
+  'url': '/multicloud/policies/all/default/policy-certificatepolicy',
+  'isExact': true,
+  'params': {
+    'name': 'policy-certificatepolicy',
+    'namespace': 'default',
+  }
+}
+
 describe('CreationTab container', () => {
   it('renders as expected', () => {
     const component = shallow(<CreationTab
       secondaryHeaderProps={{title:'testing1'}}
       updateSecondaryHeader={jest.fn()}
       mutateStatus={'DONE'}
+      match={match}
     />)
     expect(component.instance()).toMatchSnapshot()
   })
@@ -26,8 +39,8 @@ describe('CreationTab container', () => {
   it('renders as expected', () => {
     const component = shallow(<CreationTab
       secondaryHeaderProps={{title:'testing2'}}
-      updateSecondaryHeader={jest.fn()}
       handleCreateResources={jest.fn()}
+      match={match}
     />)
     expect(component.instance()).toMatchSnapshot()
     component.instance().handleCreate()
