@@ -13,6 +13,7 @@ module.exports = {
     CYPRESS_XHR: 'cy:xhr',
     CYPRESS_REQUEST: 'cy:request',
     CYPRESS_ROUTE: 'cy:route',
+    CYPRESS_INTERCEPT: 'cy:intercept',
     CYPRESS_COMMAND: 'cy:command',
 
     PLUGIN_LOG_TYPE: 'ctr:info',
@@ -24,6 +25,11 @@ module.exports = {
     WARNING: 'warning',
   },
 
+  HOOK_TITLES: {
+    BEFORE: '[[ before all {index} ]]',
+    AFTER: '[[ after all {index} ]]',
+  },
+
   PADDING: {
     LOG: Array(21).join(' '),
   }
